<?php
/**
 * Plugin Name: Unsplash
 * Plugin URI: https://github.com/xwp/unsplash-wp
 * Description: Unsplash for WordPress.
 * Version: 1.0.1
 * Author: Unsplash
 * Author URI: https://unsplash.com/
 * License: GPLv2+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: unsplash
 * Domain Path: /languages
 * Requires at least: 4.9
 * Requires PHP: 5.6
 *
 * Copyright (c) 2020 Unsplash (https://unsplash.com/)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2 or, at
 * your discretion, any later version, as published by the Free
 * Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * @package Unsplash
 */

if ( version_compare( phpversion(), '5.6.20', '>=' ) ) {
	require_once __DIR__ . '/instance.php';

	/**
	 * Setup Unsplash plugin.
	 *
	 * @codeCoverageIgnore
	 *
	 * @return void
	 */
	function _unsplash_load_plugin() {
		$unsplash_plugin = \Unsplash\get_plugin_instance();
		$unsplash_plugin->init();
	}
	add_action( 'plugins_loaded', '_unsplash_load_plugin' );
} else {
	if ( defined( 'WP_CLI' ) ) {
		WP_CLI::warning( _unsplash_php_version_text() );
	} else {
		add_action( 'admin_notices', '_unsplash_php_version_error' );
	}
}

/**
 * Admin notice for incompatible versions of PHP.
 */
function _unsplash_php_version_error() {
	printf( '<div class="error"><p>%s</p></div>', esc_html( _unsplash_php_version_text() ) );
}

/**
 * String describing the minimum PHP version.
 *
 * @return string
 */
function _unsplash_php_version_text() {
	return esc_html__( 'Unsplash plugin error: Your version of PHP is too old to run this plugin. You must be running PHP 5.6.20 or higher.', 'unsplash' );
}
